@@ -98,10 +98,10 @@ class Yaco(dict):
 
         if isinstance(data, dict):
             self.update(data)
-        elif isinstance(data, str) or isinstance(data):
+        elif isinstance(data, str) or isinstance(data, bytes):
             self.update(yaml.load(data))
         else:
-            raise Exception
+            raise Exception('cannot parse %s' % type(data))
 
     def __str__(self):
         """
@@ -461,7 +461,13 @@ class PolyYaco():
         except KeyError:
             return default
 
+    
+    def __contains__(self, key):
+        return self._merge().__contains__(key)
+
     def __getattr__(self, key):
+        if isinstance(key, int):
+            print( 'íntkey', key)
         if key[:9] == '_PolyYaco':
             try:
                 return self.__dict__[key]
